@@ -1,6 +1,8 @@
 package Reddit::Client;
 
-our $VERSION = '1.26';
+our $VERSION = '1.27';
+# 1.27  print_request_on_error
+# 1.27  added alias function get_modqueue
 # 1.26  crossposts
 # 1.252 Dropped token refresh time to 3550 (1 hour - 50 seconds)
 # 1.251 removed unnecessary passing in of variables to get_token in request
@@ -196,6 +198,7 @@ use fields (
 	'print_response',		# print response content, deprecated
 	'print_response_content',# print response content
 	'print_request', 		# print entire request
+	'print_request_on_error',# print entire request on error
 	'refresh_token', 		# oauth refresh token
 	'auth_type',			# 'script' or 'webapp'
 	'debug',
@@ -213,6 +216,7 @@ sub new {
 	$self->{print_response} = $param{print_response} || $param{print_response_conent} || 0;
 	$self->{print_request}  = $param{print_request} || 0;
 	$self->{debug}			= $param{debug}	|| 0;
+	$self->{print_request_on_error} = $param{print_request_on_error} || 0;
 
 	if ($param{password}) {
 		if (!$param{username}) {
@@ -263,8 +267,8 @@ sub version {
 sub request {
     my ($self, $method, $path, $query, $post_data) = @_;
 
-	if (!$self->{last_token} or $self->{last_token} <= time - 3550) {
-		#if ($self->{debug}) {print "getting new token\n";}
+	# 401s not being caused by this. they are a new API issue apparently.
+	if (!$self->{last_token} or $self->{last_token} <= ( time - 3600 + 55) ) {
 		# passing in username, pass, client_id, secret here did nothing
 		$self->get_token();
 	}
@@ -283,9 +287,11 @@ sub request {
         cookie     => $self->{cookie},
 		token	   => $self->{token},
 		tokentype  => $self->{tokentype},
+		last_token => $self->{last_token},
 		request_errors=> $self->{request_errors},
 		print_response=> $self->{print_response},
 		print_request=>  $self->{print_request},
+		print_request_on_error=>$self->{print_request_on_error},
     );
 
     return $request->send;
@@ -811,7 +817,7 @@ sub ban {
 	);
 	return $result;
 }
-# modqueue 
+# modqueue - why was it not called that?
 sub get_modlinks {
     	my ($self, %param) = @_;
 
@@ -838,6 +844,10 @@ sub get_modlinks {
 		@{$result->{data}{children}} 
 	];
 }
+sub get_modqueue { # alias for get_modlinks
+	my ($self, %param) = @_;
+	return $self->get_modlinks(%param);
+}
 
 # after: conversation id
 # entity: comma-delimited list of subreddit names
@@ -1120,7 +1130,6 @@ sub get_flair_options {
 		}
 	}
 
-
 	return $result;
 }
 
