@@ -6,14 +6,19 @@ use Carp;
 
 require Reddit::Client::VotableThing;
 
+# removed 4/18: media, url, ilink_flair_text, link_flair_css_class
+#
+# were these fields ever part of any comment, or were they copied form Link?
 use base   qw/Reddit::Client::VotableThing/;
-use fields qw/link_flair_text media url link_url link_flair_css_class 
+use fields qw/ 
 	  num_reports created_utc
 	  banned_by subreddit title author_flair_text is_self author media_embed
 	  permalink author_flair_css_class selftext domain num_comments clicked
 	  saved thumbnail subreddit_id approved_by selftext_html created hidden
-	  over_18 parent_id replies link_id body body_html
-	  user_reports mod_reports/;
+	  over_18 parent_id replies body body_html
+	  user_reports mod_reports
+	  link_author link_id link_permalink link_title link_url 
+/;
 
 use constant type => "t1";
 
@@ -41,6 +46,10 @@ sub remove {
 	my $self = shift;
 	return $self->{session}->remove($self->{name});
 }
+sub spam {
+	my $self = shift;
+	return $self->{session}->spam($self->{name});
+}
 sub edit {
     	my ($self, $text) = @_;
 	my $cmtid = $self->{session}->edit($self->{name}, $text);
@@ -52,6 +61,8 @@ sub delete {
 	my $cmtid = $self->{session}->delete($self->{name});
 	return $cmtid;
 }
+# The API return a 'permalink' that starts at '/r/sub..'
+# This just prepends the rest of the address
 sub get_permalink {
 	my $self = shift;
 	my $parentid = substr $self->{link_id}, 3;
