@@ -26,22 +26,26 @@ use fields (
 	'request_errors',
 	'print_response',
 	'print_request',
+	'print_request_on_error',
+	'last_token',
 );
 
 sub new {
     my ($class, %param) = @_;
     my $self = fields::new($class);
     $self->{user_agent} = $param{user_agent} || croak 'Expected "user_agent"';
-    $self->{url}        = $param{url}        || croak 'Expected "url"';
-    $self->{query}      = $param{query};
-    $self->{post_data}  = $param{post_data};
-    $self->{cookie}     = $param{cookie};
-    $self->{modhash}    = $param{modhash};
-    $self->{token}		= $param{token};
-    $self->{tokentype}	= $param{tokentype};
+    $self->{url}        	= $param{url}        || croak 'Expected "url"';
+    $self->{query}      	= $param{query};
+    $self->{post_data}  	= $param{post_data};
+    $self->{cookie}     	= $param{cookie};
+    $self->{modhash}    	= $param{modhash};
+    $self->{token}			= $param{token};
+    $self->{tokentype}		= $param{tokentype};
     $self->{request_errors} = $param{request_errors} || 0;
     $self->{print_response} = $param{print_response} || 0;
     $self->{print_request}  = $param{print_request} || 0;
+	$self->{print_request_on_error} = $param{print_request_on_error} || 0;
+	$self->{last_token}		= $param{last_token};
 
     if (defined $self->{query}) {
         ref $self->{query} eq 'HASH' || croak 'Expected HASH ref for "query"';
@@ -115,9 +119,15 @@ sub send {
     if ($res->is_success) {
         return $res->content;
     } else {
-		if ($self->{request_errors}) {
+		# print request unless we already printed it
+		if (!$self->{print_request} and $self->{print_request_on_error}) {
+			print Dumper($request);
+			print Dumper($res);
+		} elsif ($self->{request_errors}) {
+			# I dont think printing content has ever given useful information
 			croak "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
 		} else {
+			#croak sprintf("Request error: HTTP %s last token: %s time: %s", $res->status_line, $self->{last_token}, time);
 			croak sprintf("Request error: HTTP %s", $res->status_line);
 		}
     }
